aboutsummaryrefslogtreecommitdiff
path: root/src/cmd/compile/internal/pkginit
diff options
context:
space:
mode:
authorDan Scales <danscales@google.com>2021-01-15 14:12:35 -0800
committerDan Scales <danscales@google.com>2021-01-16 02:31:08 +0000
commita956a0e909e1d60c8d55339e5e591a9d1db885c4 (patch)
tree27b744813492ca6ac686bb2cf7b8ff18841f779c /src/cmd/compile/internal/pkginit
parentab3b67abfd9bff30fc001c966ab121bacff3de9b (diff)
downloadgo-a956a0e909e1d60c8d55339e5e591a9d1db885c4.tar.gz
go-a956a0e909e1d60c8d55339e5e591a9d1db885c4.zip
[dev.regabi] cmd/compile, runtime: fix up comments/error messages from recent renames
Went in a semi-automated way through the clearest renames of functions, and updated comments and error messages where it made sense. Change-Id: Ied8e152b562b705da7f52f715991a77dab60da35 Reviewed-on: https://go-review.googlesource.com/c/go/+/284216 Trust: Dan Scales <danscales@google.com> Run-TryBot: Dan Scales <danscales@google.com> TryBot-Result: Go Bot <gobot@golang.org> Reviewed-by: Matthew Dempsky <mdempsky@google.com>
Diffstat (limited to 'src/cmd/compile/internal/pkginit')
-rw-r--r--src/cmd/compile/internal/pkginit/init.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/cmd/compile/internal/pkginit/init.go b/src/cmd/compile/internal/pkginit/init.go
index 5bc66c7e1b..7cad262214 100644
--- a/src/cmd/compile/internal/pkginit/init.go
+++ b/src/cmd/compile/internal/pkginit/init.go
@@ -60,10 +60,10 @@ func Task() *ir.Name {
fns = append(fns, fn.Linksym())
}
if typecheck.InitTodoFunc.Dcl != nil {
// We only generate temps using initTodo if there
// are package-scope initialization statements, so
// something's weird if we get here.
- base.Fatalf("initTodo still has declarations")
+ base.Fatalf("InitTodoFunc still has declarations")
}
typecheck.InitTodoFunc = nil
@@ -60,10 +60,10 @@ func Task() *ir.Name {
}
if typecheck.InitTodoFunc.Dcl != nil {
- // We only generate temps using initTodo if there
+ // We only generate temps using InitTodoFunc if there
// are package-scope initialization statements, so
// something's weird if we get here.